@@ -13,7 +13,7 @@ use PPIx::Regexp::Util qw{ __instance };
 use Scalar::Util qw{ looks_like_number refaddr };
 use Test::More 0.88;
 
-our $VERSION = '0.033_01';
+our $VERSION = '0.036_01';
 
 our @EXPORT_OK = qw{
     cache_count
@@ -22,6 +22,7 @@ our @EXPORT_OK = qw{
     cmp_ok
     content
     count
+    diag
     different
     done_testing
     dump_result
@@ -29,6 +30,7 @@ our @EXPORT_OK = qw{
     finis
     equals
     navigate
+    note
     parse
     plan
     ppi
@@ -646,7 +648,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2013 by Thomas R. Wyant, III
+Copyright (C) 2009-2014 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
