@@ -48,10 +48,11 @@ use warnings;
 use base qw{ PPIx::Regexp::Node };
 
 use Carp qw{ confess };
+use PPIx::Regexp::Constant qw{ STRUCTURE_UNKNOWN };
 use PPIx::Regexp::Util qw{ __instance };
 use Scalar::Util qw{ refaddr };
 
-our $VERSION = '0.033_01';
+our $VERSION = '0.036_01';
 
 sub _new {
     my ( $class, @args ) = @_;
@@ -329,6 +330,15 @@ sub _check_for_interpolated_match {
     return;
 }
 
+sub __error {
+    my ( $self, $msg ) = @_;
+    defined $msg
+	or $msg = 'Was class ' . ref $self;
+    $self->{error} = $msg;
+    bless $self, STRUCTURE_UNKNOWN;
+    return 1;
+}
+
 1;
 
 __END__
@@ -344,7 +354,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2013 by Thomas R. Wyant, III
+Copyright (C) 2009-2014 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
